package de.hft.stuttgart.citydoctor2.gui;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Properties;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class Settings {
	
	private static final Logger logger = LogManager.getLogger(Settings.class);
	
	public static final String LAST_OPEN_FOLDER = "lastOpenFolder";
	public static final String MAXIMIZED = "maximized";
	public static final String FRAME_HEIGHT = "frameHeight";
	public static final String FRAME_WIDTH = "frameWidth";
	public static final String FRAME_X = "frameX";
	public static final String FRAME_Y = "frameY";
	public static final String LANGUAGE = "language";
	
	private static Properties props;
	
	static {
		props = new Properties();
		
		File propFile = new File("GUISettings.properties");
		if (propFile.exists()) {
			try (BufferedReader bis = new BufferedReader(new FileReader(propFile))) {
				props.load(bis);
			} catch (IOException e) {
				logger.error("Failed to load settings", e);
			} 
		}
		Runtime.getRuntime().addShutdownHook(new Thread(() -> {
			try (BufferedWriter bw = new BufferedWriter(new FileWriter(propFile))) {
				props.store(bw, "GUI configuration");
			} catch (IOException e) {
				logger.error("Failed to save settings", e);
			}
		}));
	}
	
	private Settings() {
		
	}
	
	public static String get(String name) {
		return props.getProperty(name);
	}
	
	public static void set(String name, String value) {
		props.setProperty(name, value);
	}
	
	public static String get(String name, String defaultV) {
		return props.getProperty(name, defaultV);
	}
	
	

}
